@@ -23,6 +23,9 @@
 #define PTHREAD_CORE_EVENTS_ID 0x00
 #define PTHREAD_CORE_PREFIX    GENERATE_SYSTEM_MODULE_PREFIX(PTHREAD_CORE_EVENTS_ID)
 
+#define USER_CORE_EVENTS_ID    0x08
+#define USER_CORE_PREFIX       GENERATE_SYSTEM_MODULE_PREFIX(USER_CORE_EVENTS_ID)
+
 /* thread creation/destruction */
 #define EZTRACE_NEW_THREAD          (PTHREAD_CORE_PREFIX | 0x0001)
 #define EZTRACE_END_THREAD          (PTHREAD_CORE_PREFIX | 0x0002)
@@ -32,9 +35,17 @@
 #define EZTRACE_STOP_THREAD_CREATE  (PTHREAD_CORE_PREFIX | 0x0007)
 
 #define EZTRACE_SIGNAL_RECEIVED     (PTHREAD_CORE_PREFIX | 0xf000)
-#define EZTRACE_CALLING_FUNCTION    (PTHREAD_CORE_PREFIX | 0xf001)
+#define EZTRACE_BACKTRACE_DEPTH     (PTHREAD_CORE_PREFIX | 0xf001)
+#define EZTRACE_CALLING_FUNCTION    (PTHREAD_CORE_PREFIX | 0xf002)
 
 #define EZTRACE_START_FLUSH_CODE                           0xfff5
 #define EZTRACE_STOP_FLUSH_CODE                            0xfff4
 
+#define EZTRACE_ENTER_EVENT_RED     (USER_CORE_PREFIX | 0x0008)
+#define EZTRACE_ENTER_EVENT_YELLOW  (USER_CORE_PREFIX | 0x0010)
+#define EZTRACE_ENTER_EVENT_BLUE    (USER_CORE_PREFIX | 0x0011)
+#define EZTRACE_ENTER_EVENT_PINK    (USER_CORE_PREFIX | 0x0012)
+#define EZTRACE_ENTER_EVENT_GREEN   (USER_CORE_PREFIX | 0x0013)
+#define EZTRACE_LEAVE_EVENT         (USER_CORE_PREFIX | 0x0009)
+
 #endif	/*  __EV_CODES_H__ */
