@@ -4,7 +4,6 @@
  * See COPYING in top-level directory.
  */
 
-#define _GNU_SOURCE
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -15,6 +14,7 @@
 #include "eztrace.h"
 
 extern int pptrace_debug_level;
+extern char **environ;
 
 void set_launcher_env() {
   setenv("TESTLAUNCHER", "1", 1);
@@ -153,8 +153,13 @@ int main(int argc, char **argv) {
     while (module != NULL && ++nb_modules)
       module = strtok(NULL, " ");
     free(ezt_trace);
+    if(nb_modules == 0) {
+      unsetenv("EZTRACE_TRACE");
+      ezt_trace=NULL;
+    }
   }
 
+
   char *modules[nb_modules];
   if (nb_modules != 0) {
     // we have to get EZTRACE_TRACE again because we strtok-ed it
