@@ -4,7 +4,6 @@
  * See COPYING in top-level directory.
  */
 
-#define _GNU_SOURCE 1
 #define _REENTRANT
 
 #include <unistd.h>
@@ -38,7 +37,7 @@ static void MPI_Ibcast_prolog(void *buffer __attribute__((unused)),
     MPI_Type_size(datatype, &ssize);
 
   int data_size = count * ssize;
-  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_IBCAST, (app_ptr)comm, size, rank, (app_ptr)r, data_size);
+  EZTRACE_EVENT_PACKED_6(EZTRACE_MPI_IBCAST, (app_ptr)comm, size, rank, (app_ptr)r, data_size, root);
 }
 
 static int MPI_Ibcast_core(void *buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm, MPI_Request *r)
